@@ -198,6 +198,9 @@ SERVICE_VERSIONS = {
     "cynosdb": [
         "2019-01-07"
     ],
+    "dasb": [
+        "2019-10-18"
+    ],
     "dayu": [
         "2018-07-09"
     ],
